% '#######################################
% 'Annular_liquid_holdup
% '#######################################
function res = annular_H(A, d, DLD)
% 'Calculation of liquid holdup in annular flow, using film thickness derived from force balance
% '
% ' DLD = film thickness/diameter
% ' DELTA = film thickness (m)
% ' DG  = hydraulic diameter, gas (m)
% ' Ag  = cross sectional area, gas (m2)
% ' Al  = cross sectional area, liquid (m2)
% ' Hl  = liquid holdup

    Delta = DLD * d;
    Dg = d - 2 * Delta;
    Ag = 3.14 / 4 * Dg ^ 2;
    AL = A - Ag;
    hL = AL / A;
    res = hL;
end