% '#######################################
% 'Annular_flow_dpDx
% '#######################################
function DPDX = dpdx_annular(DLD, d, A, ULS, UGS, RHOL, RHOg, VISL, beta, hL, UL, Ug)
% 'Module for testing on annular flow regime and calculating pressure gradient
% '
% 'Checking if flow is stratified,bubble or single phase
if (ULS > 0) && (UGS > 0)

% 'Calculations for annular flow
% '
% '   DLD = film thickness/diameter
% '   DELTA = film thickness (m)
% '   DG  = hydraulic diameter, gas (m)
% '   DL  = hydraulic diameter, liquid (m)
% '   Ag  = cross sectional area, gas (m2)
% '   Al  = cross sectional area, liquid (m2)
% '   Sl  = liquid circumference (m)
% '
    Delta = DLD * d;
    Dg = d - 2 * Delta;
    Ag = 3.14 / 4 * Dg ^ 2;
    AL = A - Ag;
    SL = 3.14 * d;
    DL = 4 * AL / SL;
% '
% ' ReL = Reynolds number of liquid
    REL = UL * DL * RHOL / VISL;
% ' Blasius friction factor coefficient and exponent:
    if REL < 1500 
        CT = 16;
        n = 1; 
    else
        CT = 0.046;
        n = 0.2;
    end
% '
% ' Fi = friction factor, interface
    fi = 0.005 * (1 + 300 * Delta / d);
% ' TAUi = shear stress, interface
    TAUi = fi * 0.5 * RHOg * abs(Ug - UL) * (Ug - UL);
% '
% ' Criterion for liquid film stability:
    STAB = 9.81 * (RHOL - RHOg) * d * sin(beta) * ((1 - 2 * DLD) ^ 2 - 2 * (DLD - DLD ^ 2)) - 1 / 16 * CT * RHOL * (d * RHOL / VISL) ^ (-n) * ULS ^ (2 - n) * ((DLD - DLD ^ 2) + (1 - 2 * DLD) ^ 2) / (DLD - DLD ^ 2) ^ 3;
% ' Criterion for spontaneous blockage: Liquid holdup < 0.24
% '
% ' Checking for annular flow:
    if (STAB < 0) && (hL < 0.24) 
% '
% ' Calculate pressure gradient for annular flow:
        DPDX = (4 * TAUi / (d - 2 * Delta)) + RHOg * 9.81 * sin(beta);

    else
    DPDX = 0;
    end
else
	DPDX = 0;
end
end