function res = slug_stratified0(X0, d, A, RHOL, RHOg, VISL, VISG, beta, US, UT, UL, Rsi)
% 'Calculation of force balance function value for HLD=X0
% '
% ' HLD = liquid level (m)
% ' ALf = cross sectional area, liquid (m2)
    HLD = X0;
    WF = 2 * HLD - 1;
    acosWF = acos(WF);
    ALf = 0.25 * d ^ 2 * (3.14 - acosWF + WF * sqrt(1 - WF ^ 2));
% ' Rf  = Liquid holdup in film zone
% ' Agf = cross sectional area, gas (m2)
% ' SLF = interface circumference between liquid and pipe (m)
% ' Sgf = interface circumference between gas and pipe (m)
% ' Si  = interface circumference between gas and liquid
    Rf = ALf / A;
    Agf = A - ALf;
    SLF = d * (pi - acosWF);
    Sgf = 3.14 * d - SLF;
    SI = d * sqrt(1 - WF ^ 2);
% ' LIQUID VELOCITY IN FILM:
    UF = (UT * Rf - (UT - UL) * Rsi) / Rf;
% ' GAS VELOCITY IN FILM ZONE:
    Ug = (US - UF * Rf) / (1 - Rf);
% '
% ' DLF = hydraulic diameter, liquid film
% ' Dgf = hydraulic diameter, gas
    DLF = 4 * ALf / SLF;
    Dgf = 4 * Agf / (Sgf + SI);
% ' Reynolds no of liquid in liquid film:
    RelF = abs(UF) * DLF * RHOL / VISL;
% ' Reynolds no of gas in liquid film:
    Regf = abs(Ug) * Dgf * RHOg / VISG;
% '
% ' Blasius friction factor exponent and coefficient:
    if RelF < 1500 
        Cl = 16;
        nL = 1 ;
    else
        Cl = 0.046;
        nL = 0.2;
    end
    if Regf < 1500 
        CG = 16;
        ng = 1 ;
    else CG = 0.046;
        ng = 0.2;
    end
% '
% ' SHEAR STRESS BETWEEN LIQUID AND PIPE:
    TAULf = 0.5 * RHOL * abs(UF) * UF * Cl * RelF ^ (-nL);
% ' SHEAR STRESS BETWEEN GAS AND PIPE:
    TAUgf = 0.5 * RHOg * abs(Ug) * Ug * CG * Regf ^ (-ng);
% ' SHEAR STRESS BETWEEN LIQUID AND GAS:
    TAUIf = 0.5 * RHOg * abs(Ug - UF) * (Ug - UF) * CG * Regf ^ (-ng);

    res = TAUgf * Sgf / Agf - TAULf * SLF / ALf + TAUIf * SI * (1 / ALf + 1 / Agf) - (RHOL - RHOg) * 9.81 * sin(beta);
end