% '#######################################
% 'Slug_liquidlevel_stratified
% '#######################################
function res = slug_stratified_HLD(d, A, US, RHOL, RHOg, VISL, VISG, beta, UT, Rsi, UL)
% 'Calculation of liquid level in slug film zone, modelled as stratified flow
% 'The liquid level is calculated by finding the root of the force balance function
% 'The root is located using a modified False Position method
% '
% 'Checking if flow is single phase

% 'Checking for slug flow : If no other flow regimes has been identified, slug flow is assumed
% '    If (dpdx_bubble = "NA") And (dpdx_strat = "NA") And (dpdx_ann = "NA") Then
% '
% ' Calculating slug parameters which are independent of liquid level, HLD:
% '
% '   Slug Reynolds number:
%       Res = US * RHOL * d / VISL;
% % '
% % '   CONSTANTS FOR CALCULATING FRICTION FACTOR:
%       CS = 0.046;
%       n = 0.2;
% 
%         Fs = CS * (Res) ^ (-n);
% '
% ' Starting iteration on liquid level:
        X0 = 0.01;
        X1 = 0.99;
        G0 = slug_stratified0(X0, d, A, RHOL, RHOg, VISL, VISG, beta, US, UT, UL, Rsi);
        G1 = slug_stratified0(X1, d, A, RHOL, RHOg, VISL, VISG, beta, US, UT, UL, Rsi);
        Test = G0 * G1;
        if (Test > 0) 
            X1 = 0.7;
         % Skjnner ikke hvorfor denne trengs   G1 = slug_stratified0(X1, d, A, ULS, UGS, RHOL, RHOg, VISL, VISG, beta, US, UT, UL, Rsi, AlfaS); %    G1 = slug_stratified1(X1, D, A, ULS, UGS, RHOL, RHOg, VISL, VISg, BETA#, US, UT, UL, Rsi, AlfaS)
        end
        i = 0;
        Gr = 1;
        I1 = 0;
        I0 = 0;
        while i < 100 && abs(Gr) > 0.01
            Xr = X1 - G1 * (X0 - X1) / (G0 - G1);
            Gr = slug_stratified0(Xr, d, A, RHOL, RHOg, VISL, VISG, beta, US, UT, UL, Rsi);
            Test = G0 * Gr;
            if (Test < 0) 
                X1 = Xr;
                G1 = Gr;
                I0 = I0 + 1;
                if (I0 > 2) 
                    G0 = G0 / 2;
                end
            elseif (Test > 0) 
                X0 = Xr;
                G0 = Gr;
                I1 = I1 + 1;
                if (I1 > 2) 
                    G1 = G1 / 2;
                end
            end
            i = i + 1;
        end
        
        if i>=100
            disp('Slug stratified switching to NR');
                X = 0.001;
    Gr = slug_stratified0(X, d, A, RHOL, RHOg, VISL, VISG, beta, US, UT, UL, Rsi); 
    
    i = 1;
    while abs(Gr) > 0.1 % Newton Raphson
        
      if i==1 % First iteration
          X_old = X;
          Gr_old = Gr;
          X = 0.999;
          Gr = slug_stratified0(X, d, A, RHOL, RHOg, VISL, VISG, beta, US, UT, UL, Rsi);  
%           if Gr * Gr_old >0 % Same signe implies that no solution exists
%               disp('No solution for Slug Stratified flow');
%               res = 5; % Error output
%               return;
%           end
      else
          temp = X;
          X = X - Gr/(Gr-Gr_old)*(X-X_old);
          X_old = temp;
          if X<0  % X is out of bounds
              X = X_old/2;
          elseif X>1
              X = (1+X_old)/2;
          end   

          Gr_old = Gr;
          Gr = slug_stratified0(X, d, A, RHOL, RHOg, VISL, VISG, beta, US, UT, UL, Rsi);  
      end     
      if i>100
          disp('Slug Stratified HLD failed to converge');
          res = 5; % Error output
          return;
      end
      i = i+1;
    end
    res = X;
        else
        res = Xr;
        end
% '    Else
% '    slug_stratified_HLD = "NA"
% '    End If

end