function res = stratified0(X0, d, A, ULS, UGS, RHOL, RHOg, VISL, VISG, beta)
%Calculation of force balance function value for HLD=X0

% HLD = liquid level (m)
% AL = cross sectional area, liquid (m2)
% Ag = cross sectional area, gas (m2)
% SL = interface circumference between liquid and pipe (m)
% Sg = interface circumference between gas and pipe (m)
% Si = interface circumference between gas and liquid
% DL = hydraulic diameter, liquid film (m)
% Dg = hydraulic diameter, gas (m)
% UL = liquid velocity (m/s)
% Ug = gas velocity (m/s)
    HLD = X0;
    W = 2 * HLD - 1;
    acosW = acos(W);
    AL = 0.25 * d ^ 2 * (3.14 - acosW + W * (1 - W ^ 2) ^ 0.5);
    Ag = A - AL;
    SL = d * (3.14 - acosW);
    Sg = pi * d - SL;
    SI = d * (1 - W ^ 2) ^ 0.5;
    DL = 4 * AL / SL;
    Dg = 4 * Ag / (Sg + SI);
    UL = ULS * A / AL;
    Ug = UGS * A / Ag;
% Alfa = gas void fraction
   % alfa = Ag / (AL + Ag);
% Reynolds no of liquid:
    REL = UL * DL * RHOL / VISL;
% Reynolds no of gas:
    Reg = Ug * Dg * RHOg / VISG;

% Blasius friction factor exponent and coefficient:
    if REL < 1500 
        Cl = 16;
        nL = 1; 
    else
        Cl = 0.046;
        nL = 0.2;
    end
    if Reg < 1500 
        CG = 16;
        ng = 1; 
    else
        CG = 0.046;
        ng = 0.2;
    end
% SHEAR STRESS BETWEEN LIQUID AND PIPE:
    TAUL = 0.5 * RHOL * UL ^ 2 * Cl * REL ^ (-nL);
% SHEAR STRESS BETWEEN GAS AND PIPE:
    TAUg = 0.5 * RHOg * Ug ^ 2 * CG * Reg ^ (-ng);
% SHEAR STRESS BETWEEN LIQUID AND GAS:
    TAUi = 0.5 * RHOg * abs(Ug - UL) * (Ug - UL) * CG * Reg ^ (-ng);
%
    res = TAUg * Sg / Ag - TAUL * SL / AL + TAUi * SI * (1 / AL + 1 / Ag) - (RHOL - RHOg) * 9.81 * sin(beta);
end