function [DPDX, DENS, HOLDUP] = multi_dpdx(ql, qg, deno, deng, visco, viscg, angle, d, intpt)
% d = Inner Diameter (ID)
% deno = dens_l
% visc_o = visc_l
% The variable names are changed here because the functions are written
% from the work of others.
angle = degtorad(angle);   % The angle is given by user in degrees.
visco = visco/1000; % From cp to Pa s
viscg = viscg/1000;
Area = pi * (d/2)^2;  % Cross section area [m]
usg = qg/Area;
usl = ql/Area;
um = usg + usl;
% Hs = usl/um;

% Liquid single phase:
DPDX = DPDX_liquid(d, usl, usg, deno, visco, angle);
if DPDX>0
DENS = deno;
HOLDUP = 1;
return
end

% Gas single phase:
DPDX = DPDX_gas(d, usl, usg, deng, viscg, angle);
if DPDX>0
DENS = deng;
HOLDUP = 0;
return
end

% Bubble flow:
Uoo = bubble_Uo(deno, deng, intpt, angle);
%alfa = bubble_H(usg, usl, Uoo);
% ULdb = usl / Hs;
% ULdf = usl / Hbb;
[DPDX, DENS, HOLDUP] = dpdx_bubbleflow(d, usl, usg, um, deno, deng, visco, viscg, intpt, angle, Uoo);
if DPDX>0
    return;
end

% DENS_Mat is mixture density (with slip), HOLDUP_Mat is holdup with slip.
  
% Stratified flow:
HLD = stratified_HLD(d, Area, usl, usg, deno, deng, visco, viscg, angle);  % Is this with slip or without?
if HLD ~=5 % An error has occurred.
Hst = stratified_H(Area, d, HLD);
% ULst = usl / Hst;
UGst = usg / (1 - Hst);
DPDX = dpdx_stratified(d, Area, usl, deno, deng, viscg, angle, HLD, UGst);
end
if DPDX>0
DENS = HLD * deno + (1-HLD)*deng;
HOLDUP = HLD;
return;
end

% Annular flow:
TWODLD = annular_X_FP(d, Area, usl, usg, deno, deng, visco, viscg, angle);
if TWODLD ~=5 % An error has occurred.
DLDL = 0.5 * TWODLD;
Hannn = annular_H(Area, d, DLDL);
ULannn = usl / Hannn;
UGannn = usg / (1 - Hannn);
DPDX = dpdx_annular(DLDL, d, Area, usl, usg, deno, deng, visco, angle, Hannn, ULannn, UGannn);
end
if DPDX>0
DENS = Hannn*deno + (1-Hannn)*deng;
HOLDUP = Hannn;
return;
end

% Slug flow:
Utt = slug_UT(d, usl + usg, angle);
Ubs = slug_Ub(usl + usg, deno, deng, intpt, angle);
Rsi = slug_Rsi(d, usl + usg, deno, visco, angle);
AlfaS = 1 - Rsi;
Ull = slug_UL(usl + usg, Ubs, AlfaS, Rsi);
Lss = 20 * d;
AlfaU = slug_AlfaU(usl, Ull, Rsi, Utt);
HfD = slug_stratified_HLD(d, Area, usl + usg, deno, deng, visco, viscg, angle, Utt, Rsi, Ull);
TWODLSsl = slug_annular_X_FP(d, Area, usl, usg, deno, deng, visco, angle, Utt, Ubs, AlfaS);
if HfD~=5 || TWODLSsl~=5 % Error message

if TWODLSsl == 0 
    DLDsl = 0;
else
    DLDsl = TWODLSsl * 0.5;
end
Rf = slug_Rf(d, Area, angle, DLDsl, HfD);
Uff = slug_UF(Utt, Rf, Ull, Rsi);
Lu = slug_Lu(Lss, Ull, Rsi, Uff, Rf, usl);
[DPDX, HOLDUP] = dpdx_slug_unit(DLDsl, HfD, Area, d, deno, deng, angle, AlfaS, AlfaU, Lss, Lu, usl + usg, visco, viscg, Uff);
DENS = HOLDUP*deno + (1-HOLDUP)*deng;
else
    disp('Flowrange out of bounds')
    return;
end

end