function [MolarFlowTot, MolarFlowGL, OilDensity, GasDensity, WaterDensity, y, Fv, Ml, Mv]=getInitPVTproperties(T, P, qo_sc, qgl_sc)


NRerror = 1e-2;         % Newton-Rhapson error tolerance
e = 1e-2;               % Fugacity convergence tolerance

% Pl = 37;                % Lower pressure limit [bar]
% Pu = 100;               % Upper pressure limit [bar]
% dP = 1;                 % Delta pressure [bar]


% T and p at Surface Conditions
% qo_sc is the suggested surface oil rate.
% qgl_sc is the *maximum* GL rate at surface
    

frr=1;                               % Avtivate the fugacity while-loop

R = 8.314E-5;                           % Gas constant
FluidProp = xlsread ( 'FluidProp' );    % Fluid properties
Pci = FluidProp(:,4);                   % Critical pressure [bar]
Tci = FluidProp(:,5);                   % Critical temperature [K]
%Vci = FluidProp(:,6);                   % Critical volume [m3/kmol]
kij = xlsread ( 'PR-EOS-BIPS' );        % BIP's
kij= kij + kij';
z = FluidProp(:,1);                     % Mixture composition
Mi = FluidProp(:,2);                    % Molar weight kg/kmol
AF = FluidProp(:,8);                    % Acentric factor
VTP = FluidProp(:,11);                  % PR Volume translation parameters




%% K Value estimate; Wilson equation

Pri = P ./ Pci;                       % Reduced pressure
Tri = T ./ Tci;                       % Reduced temperature



K = exp(5.37 * (1 + AF) .* (1 - 1 ./ Tri)) ./ Pri ;   % Phase equilibrium factor

m = zeros(length(z), 1);
for j = 1 : length(z)
    
    if AF(j) < 0.4
        
        m(j) = 0.37464 + 1.54226 * AF(j) - 0.26992 * AF(j)^2;
        
    else
        
        m(j) = 0.3796 + 1.485 * AF(j) - 0.1644 * AF(j)^2 + 0.01667 * AF(j)^3;

    end
end

alfa = (1 + m .* (1 - sqrt(Tri))).^2;

a = 0.45724 * R^2 * Tci.^2 ./ Pci .* alfa;

b = 0.07780 * R * Tci ./ Pci;

A = a * P / (R * T)^2;

B = b * P / (R * T);

%% Fv calculation; Rachford-Rice 

while frr>e      %Fugacity tolerance constraint
    
    
Fvmin = 1 / (1 - max(K));
Fvmax = 1 / (1 - min(K));


%syms Fv        % Matlab numerical solver
%Fv=double(vpasolve(sum(z .* (K - 1) ./ (1 + Fv(1) * (K - 1))),Fv,[Fvmin Fvmax]));


% Newton-Raphson method
Fv(1) = (Fvmin+Fvmax)/2;            % Initial guess
    
hFv = sum(z .* (K - 1) ./ (1 + Fv(1) * (K - 1)));

dhFv = - sum(z .* (K - 1).^2 ./ (Fv(1) * (K - 1) + 1).^2);

Fv(2) = Fv(1) - hFv / dhFv;

while abs(Fv(1) - Fv(2)) > NRerror     % Error tolerance
    
    Fv(1) = Fv (2);
    
    hFv = sum(z .* (K - 1) ./ (1 + Fv(1) * (K - 1)));

    dhFv = - sum(z .* (K - 1).^2 ./ (Fv(1) * (K - 1) + 1).^2);

    Fv(2) = Fv(1) - hFv / dhFv;
    
end


if Fv(2) > Fvmin && Fv(2) < Fvmax
    Fv = Fv(2);
end

% Liquid and vapor phase composition

x = z ./ (Fv .* (K - 1) + 1);

y = K .* x;


%% A / B parameters

Aij = (1-kij) .* sqrt(A * A');

AL = x' * Aij * x;

AV = y' * Aij * y;

BV = y' * B;

BL = x' * B;

syms Zl Zv

Zl = real(double(solve(Zl^3 - (1 - BL)*Zl^2 + (AL -3*BL^2-2*BL)*Zl-(AL*BL-BL^2-BL^3))));

Zl = Zl(1);


Zv = real(double(solve(Zv^3 - (1 - BV)*Zv^2 + (AV -3*BV^2-2*BV)*Zv-(AV*BV-BV^2-BV^3))));

Zv = Zv(1);


%% Fugacity

% Liquid fugacity
fl = exp(B/BL*(Zl-1)-log(Zl-BL)+AL/(2*sqrt(2)*BL)*(B/BL-2/AL*Aij*x)*log((Zl+(1+sqrt(2))*BL)/(Zl+(1-sqrt(2))*BL))+log(x*P));

% Vapor fugacity
fv = exp(B/BV*(Zv-1)-log(Zv-BV)+AV/(2*sqrt(2)*BV)*(B/BV-2/AV*Aij*y)*log((Zv+(1+sqrt(2))*BV)/(Zv+(1-sqrt(2))*BV))+log(y*P));

% Fugacity ratio
fr=fl./fv;

% K value update
K=K.*fr;

% Convergence test
frr=sum((1-fr).^2);
end



% Fv<0 => Single phase, liquid

if Fv<0
    
    Fv = 0;
    x=z;
    y=zeros(length(z),1);
    
    
% Fv>1 => Single phase, vapor
    
elseif Fv>1;
    
    Fv = 1;
    y=z;
    x=zeros(length(z),1);
    
end

%Save Fv for every pressure calculation in a vector
%Fvv=Fv;

%% Vapor properties


Mv = Mi'*y;                                      % Vapor phase molar weight

%GasDensityEOS = P * Mv*1E-3 / (Zv * R * T);   % EOS calculated vapor density
vvEOS = Zv * R * T* 1E+3/P;                      % EOS calculated vapor molar volume

c = b*1E3 .* VTP;                                   % Volume translation parameter

vvCOR = vvEOS - sum(c.*y);                    % Corrected vapor molar volume
GasDensity = Mv / vvCOR;                % Corrected vapor density



%% Liquid properties

Ml = Mi'*x;                                      % Liquid phase molar weight

vlEOS = Zl * R * T* 1E+3/P;                      % Liquid phase molar volume

c = b*1E3 .* VTP;                                   % Volume translation parameter

vlCOR = vlEOS - sum(c.*x);                    % Corrected liquid phase molar volume


OilDensity = Ml / vlCOR;                % Corrected liquid density

WaterDensity = XSteam('rho_pT', P, T-273.15);

GLMassFlow = qgl_sc * GasDensity; % Kg/s
OilMassFlow = qo_sc * OilDensity; % Kg/s

MolarFlowGL = GLMassFlow/Mv;        % Kgmol/s
MolarFlowOil = OilMassFlow/Ml;      % Kgmol/s
MolarFlowTot = MolarFlowOil/(1-Fv); % Kgmol/s

end
